--[[	*** yGuildTabard ***
Written by : Yukyuk, EU-Moonglade
--]]


-------------------------------------------------------------------------------
--  Constants
-------------------------------------------------------------------------------
local ADDON_WIDTH		= 64			-- Width of the addon frame
local ADDON_HEIGHT		= 64			-- Height of the addon frame


-------------------------------------------------------------------------------
--  AddOn configuration constants.
-------------------------------------------------------------------------------
local cfg 	= {}
cfg.addon_name 		= "yGuildTabard"
cfg.addon_version 	= "1.1"	
cfg.PLAYER_NAME		= _G.UnitName("player")
cfg.PLAYER_CLASS 	= select(2, UnitClass("player"))
cfg.PLAYER_FACTION 	= _G.UnitFactionGroup("player")
cfg.REALM_NAME 		= _G.GetRealmName()


--------------------------------------------------------------------------------
--  Tooltip
--------------------------------------------------------------------------------
local function TT_OnEnter(self)
	if IsInGuild() then
		self.tooltipText1 = GetGuildInfo("player") .. " - " .. cfg.REALM_NAME
	else	
		self.tooltipText1 = ERR_GUILD_PLAYER_NOT_IN_GUILD
	end
	
	GameTooltip:SetOwner(self, "ANCHOR_RIGHT", -64, 0)
	GameTooltip:SetText(self.tooltipText1, nil, nil, nil, nil, true)
	GameTooltip:AddLine(self.tooltipText2, nil, nil, nil, true)	
	GameTooltip:Show()
end


local function TT_OnLeave()
	GameTooltip:Hide()
end	


-------------------------------------------------------------------------------
--  Initialize database
-------------------------------------------------------------------------------	
function yGuildTabard_Initialize_Database()
	if yGuildTabardDB == nil then
		yGuildTabardDB = {}
	end	
	
	if yGuildTabardDB[cfg.REALM_NAME] == nil then
		yGuildTabardDB[cfg.REALM_NAME] = {}
	end
	
	if yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME] == nil then
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME] = {
			tabard = 1,
			UI = {
				show = true,
				point = "CENTER",
				relativePoint = "CENTER",
				pos = {
					X = 0,
					Y = 0,
				},
			},
		}
	end	
end


-------------------------------------------------------------------------------
--  Create the User interface
-------------------------------------------------------------------------------
function yGuildTabard_Create_UI()
	local yGuildTabard_UI = CreateFrame("Button","yGuildTabard_UI",UIParent,ButtonFrameTemplate)
	yGuildTabard_UI:SetPoint(yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.point,
						UIParent,
						yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.relativePoint,
						yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.pos.X,
						yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.pos.Y)	

	yGuildTabard_UI:SetFrameStrata("LOW")
	yGuildTabard_UI:SetMovable(true)
	yGuildTabard_UI:EnableMouse(true)
	yGuildTabard_UI:SetClampedToScreen(true)
	yGuildTabard_UI:SetScript("OnShow", yGuildTabard_OnShow)
	yGuildTabard_UI:SetScript("OnMouseDown", yGuildTabard_UI.StartMoving)
	yGuildTabard_UI:SetScript("OnMouseUp", function(self, button)	
		self:StopMovingOrSizing()
		local point, _, relativePoint, xOffset, yOffset = yGuildTabard_UI:GetPoint()
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.point = point
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.relativePoint = relativePoint
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.pos.X = xOffset
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.pos.Y = yOffset
	end)
	yGuildTabard_UI:SetScript("OnEnter", function(self)	
		TT_OnEnter(self)
	end)	
	yGuildTabard_UI:SetScript("OnLeave", function(self)	
		TT_OnLeave()
	end)	
	
	--  Create the background 
	yGuildTabard_UI:SetWidth(ADDON_WIDTH)
	yGuildTabard_UI:SetHeight(ADDON_HEIGHT)

	yGuildTabard_UI.TabardBorder = yGuildTabard_UI:CreateTexture(nil,"ARTWORK",nil,1)
	yGuildTabard_UI.TabardBorder:SetAllPoints()
	if yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].tabard == 1 then
		yGuildTabard_UI.TabardBorder:SetTexture("Interface\\CHATFRAME\\CHATFRAMEBACKGROUND")
	else		
		yGuildTabard_UI.TabardBorder:SetTexture("Interface\\CHARACTERFRAME\\TempPortraitAlphaMask")
	end		
	yGuildTabard_UI.TabardBorder:SetPoint("TOPLEFT", yGuildTabard_UI, 2, -2)
	yGuildTabard_UI.TabardBorder:SetPoint("BOTTOMRIGHT", yGuildTabard_UI, -2, 2)
	yGuildTabard_UI.TabardBorder:SetAlpha(1.0)	

	yGuildTabard_UI.TabardBackground = yGuildTabard_UI:CreateTexture(nil,"ARTWORK",nil,2)
	yGuildTabard_UI.TabardBackground:SetAllPoints()
	if yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].tabard == 1 then
		yGuildTabard_UI.TabardBackground:SetTexture("Interface\\CHATFRAME\\CHATFRAMEBACKGROUND")
	else		
		yGuildTabard_UI.TabardBackground:SetTexture("Interface\\CHARACTERFRAME\\TempPortraitAlphaMask")
	end	
	yGuildTabard_UI.TabardBackground:SetPoint("TOPLEFT", yGuildTabard_UI, 6, -6)
	yGuildTabard_UI.TabardBackground:SetPoint("BOTTOMRIGHT", yGuildTabard_UI, -6, 6)
	yGuildTabard_UI.TabardBackground:SetAlpha(1.0)
	
	yGuildTabard_UI.TabardEmblem = yGuildTabard_UI:CreateTexture(nil,"ARTWORK",nil,3)
	yGuildTabard_UI.TabardEmblem:SetAllPoints()
	yGuildTabard_UI.TabardEmblem:SetTexture("Interface\\GuildFrame\\GuildEmblemsLG_01")
	yGuildTabard_UI.TabardEmblem:SetPoint("TOPLEFT", yGuildTabard_UI, 4, -4)
	yGuildTabard_UI.TabardEmblem:SetPoint("BOTTOMRIGHT", yGuildTabard_UI, -4, 4)
	yGuildTabard_UI.TabardEmblem:SetAlpha(1.0)	
	
	yGuildTabard_Show()
end


-------------------------------------------------------------------------------
--  Show the User Interface?
-------------------------------------------------------------------------------
function yGuildTabard_Show()
	if yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.show then
		yGuildTabard_UI:Show()
	else
		yGuildTabard_UI:Hide()
	end
end


-------------------------------------------------------------------------------
--  Toggle the user interface
-------------------------------------------------------------------------------
function yGuildTabard_Toggle_UI()
    if yGuildTabard_UI:IsVisible() then
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.show = false
		yGuildTabard_UI:Hide()	
    else
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].UI.show = true
        yGuildTabard_UI:Show()
    end
end


-------------------------------------------------------------------------------
--	Determine the content of the frame.
-------------------------------------------------------------------------------
function yGuildTabard_SetTheContent()
	SetLargeGuildTabardTextures("player", yGuildTabard_UI.TabardEmblem, yGuildTabard_UI.TabardBackground, yGuildTabard_UI.TabardBorder)
end


-------------------------------------------------------------------------------
--  Create the Slash function.
-------------------------------------------------------------------------------
SLASH_yGuildTabard1, SLASH_yGuildTabard2 = '/yGT', '/yGuildTabard'
function SlashCmdList.yGuildTabard(msg, editbox)
	if msg == '' then
		yGuildTabard_Toggle_UI()
	elseif msg == 'square' then	
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].tabard = 1
	elseif msg == 'circle' then	
		yGuildTabardDB[cfg.REALM_NAME][cfg.PLAYER_NAME].tabard = 2		
	end	
end


-------------------------------------------------------------------------------
--	Create and handle the event frame
-------------------------------------------------------------------------------
	local yGuildTabard_event_frame = CreateFrame("Frame")
	yGuildTabard_event_frame:RegisterEvent("PLAYER_ENTERING_WORLD")
	yGuildTabard_event_frame:RegisterEvent("ADDON_LOADED")	
	yGuildTabard_event_frame:RegisterEvent("PLAYER_REGEN_DISABLED")	
	yGuildTabard_event_frame:RegisterEvent("PLAYER_REGEN_ENABLED")	
	yGuildTabard_event_frame:RegisterEvent("UNIT_MODEL_CHANGED")
		
	yGuildTabard_event_frame:SetScript("OnEvent", function(self, event, arg1)
		if event == "PLAYER_ENTERING_WORLD" then
			yGuildTabard_SetTheContent()		
			yGuildTabard_Show()
		elseif event == "GUILD_ROSTER_UPDATE" then	
			yGuildTabard_SetTheContent()		
		elseif event == "ADDON_LOADED" and arg1 == cfg.addon_name then
			yGuildTabard_Initialize_Database()
			yGuildTabard_Create_UI()
			yGuildTabard_event_frame:RegisterEvent("GUILD_ROSTER_UPDATE")			
			yGuildTabard_event_frame:UnregisterEvent("ADDON_LOADED")	
		elseif event == "PLAYER_REGEN_DISABLED" then
			yGuildTabard_UI:EnableMouse(false)	
		elseif event == "PLAYER_REGEN_ENABLED" then
			yGuildTabard_UI:EnableMouse(true)
		elseif event == "UNIT_MODEL_CHANGED" then	
			yGuildTabard_SetTheContent()			
		end
	end)